aboutsummaryrefslogtreecommitdiff
path: root/src/main/kotlin/pl/treksoft/kvision/html/Div.kt
diff options
context:
space:
mode:
authorRobert Jaros <rjaros@finn.pl>2018-03-11 23:36:01 +0100
committerRobert Jaros <rjaros@finn.pl>2018-03-11 23:45:06 +0100
commitc0fca9901a634d53d8ee0bfb119b9b2e2f017d83 (patch)
tree127bbc1cd56097694d906d9b9245164436457a76 /src/main/kotlin/pl/treksoft/kvision/html/Div.kt
parent3577c10b5c3839a06f64cb19e72788401bd7406d (diff)
downloadkvision-c0fca9901a634d53d8ee0bfb119b9b2e2f017d83.tar.gz
kvision-c0fca9901a634d53d8ee0bfb119b9b2e2f017d83.tar.bz2
kvision-c0fca9901a634d53d8ee0bfb119b9b2e2f017d83.zip
Change the name of content property in Tag component.
Diffstat (limited to 'src/main/kotlin/pl/treksoft/kvision/html/Div.kt')
-rw-r--r--src/main/kotlin/pl/treksoft/kvision/html/Div.kt12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/main/kotlin/pl/treksoft/kvision/html/Div.kt b/src/main/kotlin/pl/treksoft/kvision/html/Div.kt
index 38dc5817..6d8e05ef 100644
--- a/src/main/kotlin/pl/treksoft/kvision/html/Div.kt
+++ b/src/main/kotlin/pl/treksoft/kvision/html/Div.kt
@@ -27,17 +27,17 @@ import pl.treksoft.kvision.core.Container
* Simple component rendered as *div*.
*
* @constructor
* @param text element text
* @param rich determines if [text] can contain HTML code
*/
open class Div(
- text: String,
+ content: String,
rich: Boolean = false,
align: Align? = null,
classes: Set<String> = setOf(),
init: (Div.() -> Unit)? = null
) :
- Tag(TAG.DIV, text, rich, align, classes) {
+ Tag(TAG.DIV, content, rich, align, classes) {
init {
@Suppress("LeakingThis")
@@ -51,13 +51,13 @@ open class Div(
* It takes the same parameters as the constructor of the built component.
*/
fun Container.div(
- text: String,
+ content: String,
rich: Boolean = false,
align: Align? = null,
classes: Set<String> = setOf(),
init: (Div.() -> Unit)? = null
): Div {
- val div = Div(text, rich, align, classes).apply { init?.invoke(this) }
+ val div = Div(content, rich, align, classes).apply { init?.invoke(this) }
this.add(div)
return div
}
@@ -27,17 +27,17 @@ import pl.treksoft.kvision.core.Container
*
* @constructor
- * @param text element text
- * @param rich determines if [text] can contain HTML code
+ * @param content element text
+ * @param rich determines if [content] can contain HTML code
*/
open class Div(